![banner](https://rawcdn.githack.com/rlaphoenix/VSGAN/d7ad537bffb52bdbd1ad07c825cf016964ac57a2/banner.png)

[![Build Tests](https://img.shields.io/github/workflow/status/rlaphoenix/VSGAN/Version%20test?label=Python%203.6%2B%20builds)](https://github.com/rlaphoenix/VSGAN/actions?query=workflow%3A%22Version+test%22)
[![License](https://img.shields.io/github/license/rlaphoenix/VSGAN?style=flat)](https://github.com/rlaphoenix/VSGAN/blob/master/LICENSE)
[![DeepSource](https://deepsource.io/gh/rlaphoenix/VSGAN.svg/?label=active+issues)](https://deepsource.io/gh/rlaphoenix/VSGAN/?ref=repository-badge)
<a href="https://colab.research.google.com/github/rlaphoenix/VSGAN/blob/master/VSGAN.ipynb">
    <img align="right" src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open in Colab"/>
</a>

VSGAN is a Single Image Super-Resolution Generative Adversarial Network (GAN) which uses the VapourSynth processing framework to handle input and output image data.

## Documentation

More information, installation, building, quick start, and more, is available at [rlaphoenix.github.io/VSGAN](https://rlaphoenix.github.io/VSGAN).

The source code to the Documentation page is available on the [gh-pages branch](https://github.com/rlaphoenix/VSGAN/tree/gh-pages) and can be built and deployed locally.  
You could also just read the markdown files found in the [_docs folder](https://github.com/rlaphoenix/VSGAN/tree/gh-pages/_docs).

## License

This project is released under the MIT license.  
Please read and agree to the license before use, it can be found in the [LICENSE](LICENSE) file.
